<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\HarajCategory;
use Illuminate\Http\Request;

class AdCategoriesController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if (\request()->get('id')) {
            $ad = HarajCategory::find(\request()->get('id'));
            $rows = HarajCategory::where('parent_id', \request()->get('id'))->latest()->get();
            return view('admin.ad_categories.index', compact('rows', 'ad'));
        }
        $rows = HarajCategory::where('parent_id', null)->latest()->get();
        return view('admin.ad_categories.index', compact('rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if (\request()->get('id')) {
            $ad = HarajCategory::find(\request()->get('id'));
            return view('admin.ad_categories.create', compact('ad'));
        }
        return view('admin.ad_categories.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name_ar' => 'required',
            'name_en' => 'required',

        ]);
        $category = new HarajCategory();
        $category['name->ar'] = $request['name_ar'];
        $category['name->en'] = $request['name_en'];
        if ($request['parent_id']) {
            $category['parent_id'] = $request['parent_id'];
        }
        if ($request->hasFile('image')) $category->setImageAttribute();
        $category->save();
        toast('تمت العملية بنجاح', 'success', 'left');
        if ($request['parent_id']) {
            return redirect()->route('ad_categories.index', 'id=' . $request['parent_id']);
        }
        return redirect()->route('ad_categories.index');

    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = HarajCategory::find($id);
        if (\request()->get('id')) {
            $ad = HarajCategory::find(\request()->get('id'));
            return view('admin.ad_categories.edit', compact('row', 'ad'));
        }
        return view('admin.ad_categories.edit', compact('row'));

    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'name_ar' => 'required',
            'name_en' => 'required',
        ]);
        $category = HarajCategory::find($id);
        $category['name->ar'] = $request['name_ar'];
        $category['name->en'] = $request['name_en'];
        if ($request['parent_id']) {
            $category['parent_id'] = $request['parent_id'];
        }
        if ($request->hasFile('image')) $category->setImageAttribute();

        $category->update();
        toast('تمت العملية بنجاح', 'success', 'left');
        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        HarajCategory::destroy($id);
        toast('تمت العملية بنجاح', 'success', 'left');
        return back();
    }
}
