<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\City;
use Illuminate\Http\Request;

class AreasController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rows = City::where('type','area')->latest()->get();
        return view('admin.areas.index', compact('rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.areas.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name_ar' => 'required',
            'name_en' => 'required',

        ]);
        $city = new City();
        $city['name->ar'] = $request['name_ar'];
        $city['name->en'] = $request['name_en'];
        $city['type'] = 'area';
        $city->save();
        toast('تمت العملية بنجاح', 'success', 'left');
        return redirect()->route('areas.index');
    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $area = City::findOrFail($id);
        $rows = $area->children;
        return  view('admin.cities.index',compact('rows','area'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = City::find($id);
        return view('admin.areas.edit', compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'name_ar' => 'required',
            'name_en' => 'required'
        ]);
        $city = City::find($id);
        $city['name->ar'] = $request['name_ar'];
        $city['name->en'] = $request['name_en'];
        $city->update();
        toast('تمت العملية بنجاح', 'success', 'left');
        return redirect()->route('areas.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        City::destroy($id);
        toast('تمت العملية بنجاح', 'success', 'left');
        return back();
    }
}
