<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Ad;
use App\Models\AdComment;
use App\Models\CancelMessages;
use App\Models\Notification;
use Carbon\Carbon;
use Illuminate\Http\Request;

class HarajAdsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rows = Ad::orderByDesc('id')->get();
        return view('admin.haraj_ads.index', compact('rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $row = Ad::find($id);
        $comments_report = $row->comments()->with('reports')->get();
        return view('admin.haraj_ads.show', compact('row', 'comments_report'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = Ad::findOrFail($id);
        $cancel_messages = CancelMessages::all();

        return view('admin.haraj_ads.edit', compact('row', 'cancel_messages'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $request->validate([
            'status' => 'required|in:active,not_active'
        ]);

        Ad::whereId($id)->update([
            'status' => $request['status']
        ]);
        $haraj_ad = Ad::find($id);

        if ($request['cancel_message_text']) {
            $haraj_ad->cancel_message = $request['cancel_message_text'];

            $notification = new Notification();
            $notification['title->ar'] = "رساله من إدارة الموقع";
            $notification['title->en'] = "A message from the site administration";
            $notification['body->ar'] = $request['cancel_message_text'];
            $notification['body->en'] = $request['cancel_message_text'];
            $notification['type'] = 'admin';
            $notification['user_id'] = $haraj_ad->user_id;
            $notification['ad_id'] = $haraj_ad->id;
            $notification->save();

        } elseif ($request['cancel_message'] && $request['cancel_message_text'] == null) {
            $cancelMessage = CancelMessages::findOrFail($request['cancel_message']);

            $haraj_ad->cancel_message = $cancelMessage->body;

            $notification = new Notification();
            $notification['title->ar'] = $cancelMessage->title;
            $notification['title->en'] = $cancelMessage->title;;
            $notification['body->ar'] = $cancelMessage->body;;
            $notification['body->en'] = $cancelMessage->body;;
            $notification['type'] = 'admin';
            $notification['user_id'] = $haraj_ad->user_id;
            $notification['ad_id'] = $haraj_ad->id;
            $notification->save();
        }


        toast('تم التعديل بنجاح', 'success');
        return redirect()->route('haraj_ads.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        Ad::destroy($id);
        toast('تمت العملية بنجاح', 'success');
        return redirect()->back();
    }

    public function delete_comment($id)
    {
        AdComment::destroy($id);
        toast('تمت العملية بنجاح', 'success');
        return redirect()->back();
    }

    public function ads_search(Request $request)
    {
        $request->validate([
            'from' => 'required',
            'to' => 'required'
        ]);
        $rows = Ad::whereDate('created_at', '>=', Carbon::parse($request->from))->whereDate('created_at', '<=', Carbon::parse($request->to))->get();
        return view('admin.haraj_ads.index', compact('rows'));
    }

}
