<?php

namespace App\Http\Controllers\Site;

use App\Http\Controllers\Controller;
use App\Models\Auction;
use App\Models\AuctionCategory;
use App\Models\AuctionImages;
use App\Models\AuctionSubscription;
use App\Models\AuctionWatches;
use App\Models\Bid;
use App\Models\City;
use App\Models\FailedTransaction;
use App\Models\Favorite;
use App\Models\Notification;
use App\Models\Report;
use App\Models\Setting;
use App\Models\Transactions;
use App\Models\UserCredit;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Lang;
use Illuminate\Support\Facades\Session;
use RealRashid\SweetAlert\Facades\Alert;

class AuctionsController extends Controller
{
    public function auctions($flag)
    {

        if ($flag == 'waiting') {
            $auctions = Auction::whereStatus('waiting')->paginate(6);
            $name_auction = Lang::getLocale() == 'ar' ? 'المزادات قيد المراجعه' : 'Auctions are under review';
        } elseif ($flag == 'last') {
            $auctions = Auction::whereStatus('active')->where('date', '<', Carbon::now()->subMinutes(30))->paginate(6);
            $name_auction = Lang::getLocale() == 'ar' ? 'المزادات السابقة' : 'Previous auctions';
        } elseif ($flag == 'now') {
            $auctions = Auction::whereStatus('active')->where('date', '<=', Carbon::now())->where('end_date', '>', Carbon::now())->paginate(6);
            $name_auction = Lang::getLocale() == 'ar' ? 'المزادات الحالية' : 'Current auctions';
        } elseif ($flag == 'next') {
            $auctions = Auction::whereStatus('active')->where('date', '>', Carbon::now())->paginate(6);
            $name_auction = Lang::getLocale() == 'ar' ? 'المزادات القادمة' : 'Upcoming auctions';
        }

        return view('site.auction.auctions', compact('auctions', 'name_auction'));
    }

    public function search_auction(Request $request)
    {
        $auctions = Auction::where(['status' => 'active',
            ['title', '!=', null],
            [function ($query) use ($request) {
                if ($request->city_id) {
                    $city = City::find($request->city_id);
                    $hays = City::where('parent_id', $city->id)->pluck('id');
                    $area_city = [$city->id, $city->parent_id];
                    $all_cities = $hays->merge($area_city);
                    $query->whereIn('city_id', $all_cities);
                }
                if ($request->category_id) {
                    $query->where('category_id', $request->category_id);
                }
                if ($request->type) {
                    $query->where('type', $request->type);
                }


            }]
        ])->latest()->paginate(10);

        $name_auction = Lang::getLocale() == 'ar' ? 'البحث فى المزادات' : 'Search in auctions';
        return view('site.auction.auctions', compact('auctions', 'name_auction'));
    }

    public function auction_term()
    {
        \Session::forget(['lat', 'lng', 'choose_city_id', 'area_id', 'city_id', 'hay_id', 'images']);
        return view('site.auction.terms');
    }

    public function auction_area()
    {
        $areas = City::whereType('area')->get();
        return view('site.auction.area', compact('areas'));
    }

    public function auction_form_city(Request $request)
    {
        $request->validate([
            'area_id' => 'required'
        ]);
        Session::put('area_id', $request->area_id);

        return redirect()->route('auction_cities');
    }

    public function auction_cities()
    {


        $cities = City::whereType('city')->get();

        return view('site.auction.cities', compact('cities'));
    }

    public function auction_form_hay(Request $request)
    {
        $request->validate([
        //    'city_id' => 'required'
        ]);
      //  Session::put('city_id', $request->city_id);
        return redirect()->route('auction_hays');
    }

    public function auction_hays()
    {
       // $city_id = Session::get('city_id');
     //   $hays = City::whereParentId($city_id)->get();

        //if (count($hays) == 0) {
            //Session::put('choose_city_id', $city_id);
            return view('site.auction.upload_images');
      //  }
       // return view('site.auction.hays', compact('hays'));
    }

    public function choose_auction_hay(Request $request)
    {
        $request->validate([
            'hay_id' => 'nullable'
        ]);
        Session::put('hay_id', $request->hay_id);
        //Session::put('choose_city_id', $request->hay_id);
        return redirect()->route('choose_auction_image');
    }

    public function choose_auction_image(Request $request)
    {
        return view('site.auction.upload_images');
    }


    public function auction_map()
    {
        return view('site.auction.map');
    }

    public function auction_select_location(Request $request)
    {
        $request->validate([
            'lat' => 'required',
            'lng' => 'required'
        ], [
            'lat.required' => Lang::get('site.pleaseChooseTheLocationOnTheMap'),
            'lng.required' => Lang::get('site.pleaseChooseTheLocationOnTheMap')
        ]);
        \Session::put('lat', $request['lat']);
        \Session::put('lng', $request['lng']);
        return redirect()->route('auction_area');

    }


    public function auction_upload_images(Request $request)
    {
        $request->validate([
            'images' => 'required'
        ]);

        $images_array = [];
        $i = 1;

        foreach ($request['images'] as $image) {
            $filename = $i . '_' . time() . '.' . $image->getClientOriginalExtension();
            $image->move(public_path('images/auctions'), $filename);
            $images_array[] = $filename;
            $i++;
        }

        \Session::put('images', $images_array);

        return redirect()->route('add_auction');
    }

    public function add_auction()
    {


        $categories = AuctionCategory::latest()->get();
        return view('site.auction.add_auction', compact('categories'));
    }

    public function add_auction_form(Request $request)
    {
        if (\session()->get('city_id') == null) {
            Alert::error(Lang::get('site.pleaseEnterAuctionFromTheBeginning'));
            return redirect()->route('auction_term');
        }

        $request->validate([
            'title' => 'required',
            'type' => 'required|in:normal,direct',
            'category_id' => 'required|exists:auction_categories,id',
            'date' => 'required',
//            'date' => 'required|after:today',
            'time' => 'required',
            'description' => 'required',
            'pubg_show' => 'required|in:true,false',
            'pubg_email' => 'required_if:pubg_show,true',
            'pubg_password' => 'required_if:pubg_show,true'

        ], [
            'date.after' => trans('site.dateNotMatch'),
            'category_id.required' => trans('site.categoryIdRequired'),
            'type.required' => trans('site.typeRequired'),
        ]);


//        $time = (integer)str_replace(':', '', $request['time']);
//        if ($time > 900 && $time < 2100) {
        $auction = new Auction();
        $auction->title = $request->title;
        $auction->type = $request->type;
        $auction->category_id = $request->category_id;
        $auction->date = Carbon::parse($request->date . $request->time);
        $auction->end_date = Carbon::parse($request->date . $request->time)->addMinutes(30);
        $auction->check_hour = Carbon::parse($request->date . $request->time)->addMinutes(90);
        $auction->check_twelve = Carbon::parse($request->date . $request->time)->addMinutes(750);
        $auction->time = $request['time'];
        $auction->description = $request->description;
        $auction->pubg_email = $request->pubg_email;
        $auction->pubg_password = $request->pubg_password;
        $auction->lat = Session::get('lat');
        $auction->lng = Session::get('lng');
        $auction->city_id = Session::get('choose_city_id');
        $auction->status = 'waiting';
        $auction->user_id = Auth::user()->id;
        $auction->save();


        $code = "MZ0" . $auction->id;
        $auction->code = $code;
        $auction->update();
        $images = Session::get('images');
        foreach ($images as $image) {
            $auction_image = new AuctionImages();
            $auction_image->image = $image;
            $auction_image->auction_id = $auction->id;
            $auction_image->save();
        }

        \Session::forget(['lat', 'lng', 'choose_city_id', 'city_id', 'hay_id']);

        toast(Lang::get('site.auctionSuccessfully'), 'success');

        return redirect()->route('user_auctions', ['flag' => 'waiting', 'user_id' => \Auth::id()]);
//        } else {
//            Alert::error(trans('site.timeNotMatch'));
//            return back();
//        }

    }

    public function auction_details($id)
    {

        $row = Auction::find($id);
        $start_date = \Carbon\Carbon::parse($row->date);
        $end_date = \Carbon\Carbon::parse($row->date)->addMinutes(30);
//        dd($start_date,$end_date,Carbon::now());

        $bids = $row->bids()->latest()->take(10)->get();
        if (\Auth::check()) {

            $check = AuctionWatches::where(['user_id' => \Auth::user()->id, 'auction_id' => $id])->first();
            if (!$check) {
                AuctionWatches::create(['user_id' => \Auth::user()->id, 'auction_id' => $id]);
            }

        }
        return view('site.auction.auction_details', compact('row', 'bids'));
    }

    function getAuctionFavouriteCount($id)
    {
        return \App\Models\Favorite::where('auction_id', $id)->count();
    }

    public function favourite_auction(Request $request)
    {
        $validator = \Validator::make($request->all(), [
            'auction_id' => 'required'
        ]);

        if (!\Auth::check()) return response()->json(['value' => 'false', 'msg' => trans('site.login_first')]);

        if ($validator->passes()) {

            $check = Favorite::where(['user_id' => \Auth::user()->id, 'auction_id' => $request['auction_id']])->first();
            if ($check) {
                $check->delete();
                $removed_class = 'fa-heart';
                $added_class = 'fa-heart-o';
                $message = trans('site.unfavoured');
                $count = $this->getAuctionFavouriteCount($request['auction_id']);

            } else {

                Favorite::create(['user_id' => \Auth::user()->id, 'auction_id' => $request['auction_id']]);
                $removed_class = 'fa-heart-o';
                $added_class = 'fa-heart';
                $message = trans('site.liked');
                $count = $this->getAuctionFavouriteCount($request['auction_id']);
            }

            return response()->json(['value' => 'true', 'data' => $message, 'removed_class' => $removed_class, 'count' => $count, 'added_class' => $added_class]);


        } else {

            return response()->json(['value' => 'false', 'msg' => $validator->errors()->first()]);

        }
    }

    public function report_auction($auction_id, Request $request)
    {
        $request->validate([
            'note' => 'required'
        ]);

        $request['user_id'] = \Auth::user()->id;
        $request['auction_id'] = $auction_id;
        Report::create($request->all());
        toast(trans('site.report_sent'), 'success');
        return redirect()->back();
    }

    public function edit_auction($id)
    {
        $row = Auction::find($id);
        $categories = AuctionCategory::latest()->get();
        $start_date = Carbon::parse($row->date);
        $end_date = Carbon::parse($row->date)->addMinutes(30);
        if ($start_date <= Carbon::now() && $end_date >= Carbon::now()) {
            Alert::error(Lang::get('site.sorryEditAuction'));
            return redirect()->back();
        }
        return view('site.auction.edit_auction', compact('row', 'categories'));
    }

    public function update_auction($id, Request $request)
    {

        $request->validate([
            'title' => 'required',
            'type' => 'required|in:normal,direct',
            'category_id' => 'required|exists:auction_categories,id',
            'date' => 'required|after:today',
            'time' => 'required',
            'description' => 'required'
        ], [
            'date.after' => trans('site.dateNotMatch'),
            'category_id.required' => trans('site.categoryIdRequired'),
            'type.required' => trans('site.typeRequired'),
        ]);


        $time = (integer)str_replace(':', '', $request['time']);
        if ($time > 900 && $time < 2100) {
            $auction = Auction::find($id);
            $auction->title = $request->title;
            $auction->type = $request->type;
            $auction->category_id = $request->category_id;
            $auction->date = Carbon::parse($request->date . $request->time);
            $auction->end_date = Carbon::parse($request->date . $request->time)->addMinutes(30);
            $auction->check_hour = Carbon::parse($request->date . $request->time)->addMinutes(90);
            $auction->check_twelve = Carbon::parse($request->date . $request->time)->addMinutes(750);
            $auction->description = $request->description;
            $auction->time = $request['time'];
            $auction->update();

            $i = 1;

            $images = $request->images;
            if ($images) {
                foreach ($images as $image) {
                    $auction_image = new AuctionImages();
                    $filename = $i . '_' . time() . '.' . $image->getClientOriginalExtension();
                    $image->move(public_path('images/auctions'), $filename);
                    $auction_image->image = $filename;
                    $auction_image->auction_id = $auction->id;
                    $auction_image->save();
                }
            }
            toast(Lang::get('site.theAuctionHasBeenSuccessfullyModified'), 'success');

            return redirect()->route('auction_details', $auction->id);
        } else {
            Alert::error(trans('site.timeNotMatch'));
            return back();
        }
    }

    public function delete_image_auction($id)
    {
        AuctionImages::find($id)->delete();
        toast(Lang::get('site.auctionImageSuccessfullyDeleted'), 'success');
        return redirect()->back();

    }

    public function subscribe_auction($auction_id)
    {
        $auction = Auction::findOrFail($auction_id);

        if (\Auth::check() && \Auth::user()->id == $auction->user_id) {
            Alert::error('عفوا لا يمكن لصاحب المزاد الإشتراك في المزاد الخاص بة');
            return redirect()->back();
        }

        if (\Auth::check() && \Auth::user()->registrationId != null) {
            AuctionSubscription::create([
                'user_id' => \Auth::user()->id,
                'auction_id' => $auction_id
            ]);
            Alert::success('تم الاشتراك فى المزاد بنجاح');
            return redirect()->back();
        }

        return view('site.auction.payment', compact('auction_id'));
    }

    public function subscribe_auction_payment(Request $request)
    {
        $request->validate([
            'holder_name' => 'required',
            'number' => 'required',
            'cvv' => 'required',
            'end_month' => 'required',
            'auction_id' => 'required',
            'end_year' => 'required',
            'method' => 'required|in:mada,masterCard'
        ]);


        $payment_status = $this->payment(1, $request->number, $request->holder_name, $request->end_month, $request->end_year, $request->cvv, $request['method']);
        $data = json_decode($payment_status);

        if ($data->result->code == '000.100.110') {

            $request['user_id'] = \Auth::user()->id;
            UserCredit::create($request->all());

            AuctionSubscription::create([
                'user_id' => \Auth::user()->id,
                'auction_id' => $request['auction_id']
            ]);

            Alert::success(Lang::get('site.successAuctionIN'));
            return redirect()->route('auction_details', $request['auction_id']);


        } else {

            Alert::error(Lang::get('site.failedStock'));
            return redirect()->back();
        }

    }

    public function delivery_codes($auction_id)
    {
        $auction = Auction::find($auction_id);
        return view('site.auction.delivery_code', compact('auction'));
    }

    public function check_receive_code(Request $request)
    {
        $request->validate([
            'code' => 'required',
            'auction_id' => 'required'
        ]);

        $auction = Auction::find($request['auction_id']);
        if ($auction->code == $request['code']) {
            $auction->code_recieve = 'true';
            $auction->update();
            Alert::success(trans('site.codeReceiveSuccess'));
            return redirect()->route('auction_details', $request['auction_id']);
        } else {
            toast(trans('site.code_error'), 'error');
            return redirect()->back();

        }


    }

// RECURRING PAYMENT
    public function payment($amount, $user)
    {

        $registrationId = $user->registrationId;
        $randomCode = rand(1111, 9999);
        $url = "https://oppwa.com/v1/registrations/$registrationId/payments";
        $data = "entityId=8ac9a4ca7c30b119017c500e86cd65c9" .
            "&amount=$amount" .
            "&currency=SAR" .
            "&paymentType=DB" .
            "&shopperResultUrl=https://som-sa.com/test_payment" .
            "&recurringType=REPEATED" .
            "&merchantTransactionId=$randomCode" .
            "&standingInstruction.type=UNSCHEDULED" .
            "&standingInstruction.source=MIT";


        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            'Authorization:Bearer OGFjOWE0Y2M3YTVjMDVlYjAxN2E2MTY2ZjczNTQzYjB8cDVmUGprUjNUTQ=='));
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);// this should be set to true in production
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        $responseData = curl_exec($ch);
        if (curl_errno($ch)) {
            return curl_error($ch);
        }
        curl_close($ch);
        return $responseData;

    }


    public function confirmation_sale(Request $request)
    {
        $auction = Auction::find($request->auction_id);
        $auction_date = $auction->date;
        $auction_end_date = $auction->end_date;
        $bid = Bid::find($request->bid_id);
        $credit = $bid->user->user_credit;
        $price = sprintf("%.2f", $bid->price);
//        dd($price,$bid->price,round($bid->price,2));
//        $price = round($bid->price,2);

        $payment_status = $this->payment($price, $bid->user);
        $data = json_decode($payment_status);

        if ($data->result->code == '000.100.112' || $data->result->code == '000.100.110' || $data->result->code == '000.000.000') {
            $commission = 0;
            $setting = Setting::first();
            $haraj_commission = $setting->haraj_commission ? $setting->haraj_commission : $commission;

            $auction->price = $bid->price;
            $auction->paid = 'true';
            $auction->date = Carbon::parse($auction_date)->subMinutes(30);
            $auction->end_date = Carbon::parse($auction_end_date)->subMinutes(30);
            $auction->winner_id = $bid->user->id;
            $auction->owner_accept = 'true';
            $auction->code = $bid->user->id . rand('111', '999') . $auction->id;
            $auction->commission = round($bid->price * $haraj_commission / 100, 1);
            $auction->update();


            if ($auction->pubg_email) {
                $auction->code_recieve = 'true';
                $auction->update();

                $notification_winner = new Notification();
                $notification_winner->user_id = $bid->user->id;
                $notification_winner->auction_id = $auction->id;
                $notification_winner->type = 'order';
                $notification_winner['title->ar'] = "لقد ربحت المزاد $auction->title ";
                $notification_winner['title->en'] = "You have won the auction $auction->title";
                $notification_winner['body->ar'] = "مبروك لقد ربحت المزاد";
                $notification_winner['body->en'] = "Congratulations, you won the auction";
                $notification_winner->save();

                toast(Lang::get('site.auctionRequestNotifications'), 'success');
            } else {
                $notification_winner = new Notification();
                $notification_winner->user_id = $bid->user->id;
                $notification_winner->auction_id = $auction->id;
                $notification_winner->type = 'auction';
                $notification_winner['title->ar'] = "لقد ربحت المزاد $auction->title ";
                $notification_winner['title->en'] = "You have won the auction $auction->title";
                $notification_winner['body->ar'] = "مبروك لقد ربحت المزاد وهذا هوا رمز الاستلام من صاحب المزاد برجاء التواصل معه الرمز هو : $auction->code";
                $notification_winner['body->en'] = "Congratulations, you won the auction, and this is the receipt code from the auctioneer. Please contact him. The code is : $auction->code";
                $notification_winner->save();

                $notification_owner = new Notification();
                $notification_owner->user_id = $auction->user_id;
                $notification_owner->auction_id = $auction->id;
                $notification_owner->type = 'auction';
                $notification_owner['title->ar'] = "رمز تسليم المزاد $auction->title ";
                $notification_owner['title->en'] = "Auction delivery code $auction->title";
                $notification_owner['body->ar'] = "  برجاء التواصل معه حتى يتم التسليم بنجاح " . $auction->winner->username . "لقد ربح المزاد";
                $notification_owner['body->en'] = "won the auction" . $auction->winner->username . "Please contact him for successful delivery";
                $notification_owner->save();
                toast(Lang::get('site.codeReceiveSuccess'), 'success');
            }
            return redirect()->back();
        }


        // نسجل اللي فشل العملية ان البطاقه فيها مشكلة


        FailedTransaction::create([
            'user_id' => $bid->user_id,
            'auction_id' => $auction->id,
            'details' => 'تم فشل عملية الدفع لعدم وجود رصيد ومشكلة في البيانات'
        ]);


        toast(Lang::get('site.theOperationFailed'), 'error');
        return redirect()->back();
    }

    public function test_payment(Request $request)
    {
        dd($request->all());
    }

    public function payment_auction_in($id)
    {
        $auction = Auction::find($id);
        $bid = Bid::where('auction_id', $id)->orderByDesc('id')->first();
        if ($auction->paid != 'true') {
            $bid = Bid::where('action_id', $id)->orderByDesc('id')->first();
            $credit = $bid->user->user_credit;
            $price = sprintf("%.2f", $bid->price);
            $payment_status = $this->payment($price, $bid->user);


            $data = json_decode($payment_status);

            if ($data->result->code == '000.100.112' || $data->result->code == '000.100.110' || $data->result->code == '000.000.000') {
                $auction->price = $bid->price;
                $auction->paid = 'true';
                $auction->winner_id = $bid->user->id;
                $auction->owner_accept = 'true';
                $auction->code = $bid->user->id . rand('111', '999') . $auction->id;
                $auction->update();

                $notification_winner = new Notification();
                $notification_winner->user_id = $bid->user->id;
                $notification_winner->auction_id = $auction->id;
                $notification_winner->type = 'auction';
                $notification_winner['title->ar'] = "لقد ربحت المزاد $auction->title ";
                $notification_winner['title->en'] = "You have won the auction $auction->title";
                $notification_winner['body->ar'] = "مبروك لقد ربحت المزاد وهذا هوا رمز الاستلام من صاحب المزاد برجاء التواصل معه الرمز هو : $auction->code";
                $notification_winner['body->en'] = "Congratulations, you won the auction, and this is the receipt code from the auctioneer. Please contact him. The code is : $auction->code";
                $notification_winner->save();

                $notification_owner = new Notification();
                $notification_owner->user_id = $auction->user_id;
                $notification_owner->auction_id = $auction->id;
                $notification_owner->type = 'auction';
                $notification_owner['title->ar'] = "رمز تسليم المزاد $auction->title ";
                $notification_owner['title->en'] = "Auction delivery code $auction->title";
                $notification_owner['body->ar'] = "  برجاء التواصل معه حتى يتم التسليم بنجاح " . $auction->winner->username . "لقد ربح المزاد";
                $notification_owner['body->en'] = "won the auction" . $auction->winner->username . "Please contact him for successful delivery";
                $notification_owner->save();
                if (Auth::user()->id != $bid->user_id) {
                    toast(Lang::get('site.theAuctionHasEnded'), 'success');
                    return redirect()->back();
                }
                toast(Lang::get('site.codeReceiveSuccess'), 'success');
                return redirect()->back();

            }


            // نسجل اللي فشل العملية ان البطاقه فيها مشكلة


            FailedTransaction::create([
                'user_id' => $bid->user_id,
                'auction_id' => $auction->id,
                'details' => 'تم فشل عملية الدفع لعدم وجود رصيد ومشكلة في البيانات'
            ]);

            if (Auth::user()->id != $bid->user_id) {
                toast('تم انتهاء المزاد', 'success');
                return redirect()->back();
            }
            toast(Lang::get('site.failedStock'), 'error');
            return redirect()->back();

        } else {
            toast(Lang::get('site.theAuctionHasEnded'), 'success');
            return redirect()->back();
        }
    }

    public function delete_auction($auction_id)
    {
        $auction = Auction::findOrFail($auction_id);
        if ($auction->user_id == \Auth::user()->id) {
            Auction::destroy($auction_id);
            toast('تم الحذف بنجاح', 'success');
            return redirect()->route('home');
        } else {
            toast('لا يمكنكم حذف الإعلان', 'error');
            return redirect()->route('home');
        }
    }


    public function next_auction(Request $request)
    {

        $next_auctions = Auction::where(['time' => $request->time, 'status' => 'active'])->where('date', '>', Carbon::now())->take(4)->get();

        $view = view('site.controllers.next_auction', compact('next_auctions'))->render();
        return response()->json(['html' => $view]);
    }


}

