<?php

namespace App\Http\Controllers\Site;

use App\Http\Controllers\Admin\CommissionTransfer;
use App\Http\Controllers\Controller;
use App\Models\Auction;
use App\Models\Bank;
use App\Models\Notification;
use App\Models\Setting;
use App\Models\Suggest;
use App\Models\User;
use App\Models\UserRates;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Lang;
use Illuminate\Support\Facades\Session;
use RealRashid\SweetAlert\Facades\Alert;

class UsersController extends Controller
{
    public function register_store(Request $request)
    {
        $this->validate($request, [
            'username' => 'required|unique:users,username',
            'email' => 'required|email|unique:users,email',
            'mobile' => 'required|unique:users,mobile',
            'password' => 'required|confirmed|min:6',
            'account_name' => 'required',
            'bank_account' => 'required',
            // 'country_code' => 'required',
            'bank_name' => 'required',
//            'iban_number'=>'required'
        ]);
        $user = new User();
        $user->username = $request->username;
        $user->email = $request->email;
        $user->mobile = $request->mobile;
        $user->country_code = $request->country_code;
        $user->bank_name = $request['bank_name'];
        $user->bank_account = $request['bank_account'];
        $user->account_name = $request['account_name'];
        $user->iban_number = $request['iban_number'];
        $user->status = 'not_active';
        $user->verified = 'false';
        $user->password = bcrypt($request->password);
        $user->save();
        $user->code = rand('1111', '9999') . $user->id;
        $user->update();
        $message = "عميلنا العزيز الكود الخاص بكم لموقع سوم كوم هو $user->code";
        $mobile = $user->country_code . $user->mobile;
       // shamel_sms($mobile, $message);

        toast(Lang::get('data.send_code'), 'success', 'left');

        return redirect()->route('activate_account');

    }

    public function activate_account_store(Request $request)
    {
        $this->validate($request, [
            'code' => 'required'
        ]);
        $user = User::where('code', $request->code)->first();
        if (!$user) {
            toast(Lang::get('data.code_error'), 'error', 'left');
            return redirect()->back();
        }
        $user->status = 'active';
        $user->verified = 'true';
        $user->code = '';
        $user->update();
        Auth::login($user);
        toast(Lang::get('data.active_account'), 'success', 'left');
        return redirect()->route('home');
    }

    public function logout()
    {

        $user = \Auth::user();
        $user->last_online = Carbon::now();
        $user->update();
        Auth::logout();

        toast(Lang::get('data.exit'), 'success', 'left');
        return redirect()->route('home');
    }

    public function login_form()
    {
//        if (Auth::check()) {
//            return redirect()->route('home');
//        }
        return view('site.users.login');

    }

    public function authentication(Request $request)
    {
        $this->validate($request, [
            'mobile' => 'required',
            'password' => 'required',
            'g-recaptcha-response' => 'recaptcha',
        ]);
        $mobile = $request['mobile'];
        if (is_numeric($request->mobile)) {
            $auth_in = 'mobile';

            $first_three = substr($request['mobile'], 0, 3);

            if ($first_three == 966) {
                $mobile = substr($request['mobile'], 3);


            } else {
                $mobile = $request['mobile'];
            }


//            if ($mobile[0] != '9') {
//                $mobile = "966" . $request['mobile'];
//            }


        } else {
            $auth_in = 'username';
        }


        if (\Auth::attempt([$auth_in => $mobile, 'password' => $request['password'], 'status' => 'active'])) {
            $user = Auth::user();
            if ($user->verified == "false") {

                $code = rand(11111, 99999) . $user->id;
                $user->code = $code;
                $user->update();
                //send code to mobile
                $message = "عميلنا العزيز الكود الخاص بكم لموقع سوم كوم هو $user->code";
                $mobile = $user->country_code . $user->mobile;
             //   shamel_sms($mobile, $message);

                Auth::logout();

                toast(Lang::get('data.send_code'), 'success', 'left');
                return redirect()->route('activate_account');
            }
            $user->last_online = null;
            $user->update();
            toast(Lang::get('data.hello'), 'success', 'left');
            return redirect()->route('home');
        } else {
            if (is_numeric($request->mobile)) {
                toast(Lang::get('data.mobileNumberOrPasswordIsWrong'), 'error', 'left');
            } else {
                toast(Lang::get('data.theUsernameOrPasswordIsWrong'), 'error', 'left');
            }
            return redirect()->back();
        }
    }

    public function forget_password_post(Request $request)
    {
        $this->validate($request, [
            'mobile' => 'required|exists:users,mobile'
        ]);
        $mobile = $request['mobile'];


        $user = User::where('mobile', $mobile)->first();

        $code = rand('1111', '9999') . $user->id;
        $user->code = $code;
        $user->save();
        $message = "عميلنا العزيز الكود الخاص بكم لموقع سوم كوم هو $user->code";
      //  shamel_sms($user->country_code . $user->mobile, $message);
        Session::put('code', $code);
        toast(Lang::get('data.theConfirmationCodeHasBeenSentToTheMobile'), 'success', 'left');

        return redirect()->route('user_check_code');

    }

    public function user_check_code()
    {
        return view('site.users.check_code');
    }

    public function check_code(Request $request)
    {
        $this->validate($request, [
            'code' => 'required|exists:users,code'
        ]);
        $user = User::where('code', $request->code)->first();

        if ($user->code == Session::get('code')) {
            $user->code = null;
            $user->update();
            Session::forget('code');
            Session::put('user', $user->id);
            toast(Lang::get('data.done_code'), 'success', 'left');
//            return view('site.users.forget_change_password');


            return redirect()->route('user_forget_change_password');
        }
        toast(Lang::get('data.code_error'), 'error', 'left');
        return redirect()->route('user_check_code');
    }

    public function forget_change_password(Request $request)
    {
        $this->validate($request, [
            'password' => 'required|confirmed|min:6'
        ]);
        $user = User::find(Session::get('user'));

        $user->password = bcrypt($request->password);
        $user->update();
        Session::forget('user');
        Auth::login($user);

        toast(Lang::get('data.hello'), 'success', 'left');
        return redirect()->route('home');
    }

    public function profile()
    {
        $user = \Auth::user();
        $waiting_auctions = $user->auctions()->whereStatus('waiting')->take(4)->get();
        $now_auctions = $user->auctions()->where('date', '<=', Carbon::now())->where('end_date', '>', Carbon::now())->latest()->take(4)->get();
        $last_auctions = $user->auctions()->whereStatus('active')->where('date', '<', Carbon::now()->subMinutes(30))->take(4)->get();
        $next_auctions = $user->auctions()->whereStatus('active')->where('date', '>', Carbon::now())->take(4)->get();
        $rows = $user->ads()->whereStatus('active')->latest()->take(4)->get();

        $adOrders = $user->orders()->latest()->get();

        return view('site.users.profile', compact('rows', 'now_auctions', 'user', 'waiting_auctions', 'next_auctions', 'last_auctions', 'adOrders'));
    }

    public function change_old_password(Request $request)
    {
        $validator = \Validator::make($request->all(), [
            'old_password' => 'required',
            'new_password' => 'required|confirmed'
        ]);
        if ($validator->passes()) {
            $user = \Auth::user();
            if (\Hash::check($request['old_password'], $user->password)) {
                $user->password = bcrypt($request['new_password']);
                $user->update();
                toast(trans('site.changed_success'), 'success');
            } else {

                Alert::error(trans('site.wrong_old_password'));
            }


        } else {
            Alert::error($validator->errors()->first());

        }
        return redirect()->back();
    }

    public function change_email(Request $request)
    {
        $validator = \Validator::make($request->all(), [
            'email' => 'required|email|unique:users,email,' . \Auth::user()->id
        ]);

        if ($validator->passes()) {

            \Auth::user()->update([
                'email' => $request['email']
            ]);
            toast(trans('site.email_changed'), 'success');
        } else {
            Alert::error($validator->errors()->first());
        }
        return redirect()->back();
    }

    public function change_mobile(Request $request)
    {
        $validator = \Validator::make($request->all(), [
            'mobile' => 'required|unique:users,mobile,' . \Auth::user()->id
        ]);

        if ($validator->passes()) {

            \Auth::user()->update([
                'mobile' => $request['mobile']
            ]);
            toast(trans('site.mobile_changed'), 'success');
        } else {
            Alert::error($validator->errors()->first());
        }
        return redirect()->back();
    }

    public function change_username(Request $request)
    {
        $validator = \Validator::make($request->all(), [
            'username' => 'required|unique:users,username,' . \Auth::user()->id
        ]);

        if ($validator->passes()) {

            \Auth::user()->update([
                'username' => $request['username']
            ]);
            toast(trans('site.username_changed'), 'success');
        } else {
            Alert::error($validator->errors()->first());
        }
        return redirect()->back();
    }

    public function change_image(Request $request)
    {
        $validator = \Validator::make($request->all(), [
            'image' => 'required|image'
        ]);
        if ($validator->passes()) {

            if ($request->hasFile('image')) {
                $user = \Auth::user();
                $user->setImageAttribute();
                $user->update();
                toast(trans('site.image_changed'), 'success');

            }
        } else {
            Alert::error($validator->errors()->first());
        }
        return redirect()->back();

    }

    public function user_auctions($flag, $user_id)
    {
        $user = User::findOrFail($user_id);
        if ($flag == 'waiting') {
            $auctions = $user->auctions()->whereStatus('waiting')->paginate(6);
            $name_auction = Lang::getLocale() == 'ar' ? 'المزادات قيد المراجعه' : 'Auctions are under review';
        } elseif ($flag == 'last') {
            $auctions = $user->auctions()->whereStatus('active')->where('date', '<', Carbon::now()->subMinutes(30))->paginate(6);
            $name_auction = Lang::getLocale() == 'ar' ? 'المزادات السابقة' : 'Previous auctions';
        } elseif ($flag == 'now') {
            $auctions = $user->auctions()->where('date', '<=', Carbon::now())->where('end_date', '>', Carbon::now())->latest()->paginate(6);
            $name_auction = Lang::getLocale() == 'ar' ? 'المزادات الحالية' : 'Current auctions';
        } elseif ($flag == 'next') {
            $auctions = $user->auctions()->whereStatus('active')->where('date', '>', Carbon::now())->paginate(6);
            $name_auction = Lang::getLocale() == 'ar' ? 'المزادات القادمة' : 'Upcoming auctions';
        }

        return view('site.users.user_auctions', compact('auctions', 'name_auction'));
    }

    public function complaints()
    {
        return view('site.users.complaints');
    }

    public function send_complaint(Request $request)
    {
        $request->validate([
            'note' => 'required',
            'type' => 'required|in:complaint,suggest'
        ]);
        $request['user_id'] = \Auth::user()->id;
        Suggest::create($request->all());
        toast(trans('site.sent_success'), 'success');
        return redirect()->back();
    }

    public function payment()
    {
        $banks = Bank::all();
        return view('site.pages.payment', compact('banks'));
    }

    public function commission()
    {
        return view('site.users.commission');
    }

    public function calculate_commission(Request $request)
    {

        if ($request->amount) {
            $amount = $request->amount * Setting::first()->value('haraj_commission');
            $data = $amount / 100;
            return response()->json(['status' => 1, 'data' => round($data)]);
        }
    }

    public function favourites()
    {
        $user = Auth::user();
        $rows = $user->favourite_ads()->where('auction_id', null)->paginate(10);
        $auctions = $user->favourite_auctions()->where('ad_id', null)->paginate(1);
        return view('site.users.favorites', compact('rows', 'auctions'));
    }

    public function user_harajs($user_id)
    {
        $user = User::findOrFail($user_id);
        $rows = $user->ads()->whereStatus('active')->latest()->paginate(10);
        return view('site.haraj.harajs', compact('rows'));

    }

    public function notifications()
    {
        $user = Auth::User();
        $rows = $user->notifications()->latest()->paginate(10);
        return view('site.pages.notifications', compact('rows'));
    }

    public function delete_notifications()
    {
        $user = Auth::User();
        Notification::where('user_id', $user->id)->delete();

        toast(trans('site.notifications_deleted'), 'success');
        return redirect()->back();
    }

    public function rate_user($user_id, Request $request)
    {
        $this->validate($request, [
            'rate' => 'required',
            'note' => 'required'
        ]);


        UserRates::create([
            'user_id' => \Auth::user()->id,
            'rated_id' => $user_id,
            'rate' => $request['rate'],
            'note' => $request['note']
        ]);

        toast(Lang::get('site.rated'), 'success');
        return redirect()->back();
    }

    public function payment_submit(Request $request)
    {
        $this->validate($request, [
            'bank_id' => 'required|exists:banks,id',
            'image' => 'required|image'
        ]);


        \App\Models\CommissionTransfer::create([
            'user_id' => \Auth::user()->id,
            'bank_id' => $request->bank_id,
            'image' => $request->image,
        ]);

        toast('تم ارسال الايصال', 'success');
        return redirect()->back();
    }

    public function rate_user_ajax(Request $request)
    {


        if (\Auth::check()) {

            if (\Auth::user()->id == $request['user_id']) {
                return response()->json(['value' => false, 'data' => Lang::get('site.cantRateYourself')]);
            }
            $check = UserRates::where(['user_id' => \Auth::user()->id, 'rated_id' => $request['user_id']])->first();


            if ($check) {
                $check->rate = $request['rate'];
                $check->update();
            } else {
                UserRates::create(['user_id' => \Auth::user()->id, 'rated_id' => $request['user_id'], 'rate' => $request['rate']])->first();
            }
            $user_rate = getUserRateRound($request['user_id']);
            $user_id = $request['user_id'];
            $new_rate = view('site.users.rate_line', compact('user_rate', 'user_id'))->render();
            $user = User::findOrFail($request['user_id']);
            $new_stars = view('site.users.new_stars', compact('user'))->render();
            return response()->json(['value' => true, 'data' => Lang::get('site.rated'), 'new_rate' => $new_rate, 'new_stars' => $new_stars]);

        } else {
            return response()->json(['value' => false, 'msg' => Lang::get('site.login_first')]);
        }
    }
}

