<?php

namespace App\Http\Controllers\Site;

use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\Request;
use Illuminate\Support\Facades\Route;

$locale = Request::segment(1);

if ($locale == Config::get('app.available_locales')) {
    \App::setLocale($locale);

} else {

    $locale = null;

}

Route::view('test_socket', 'test');
Route::get('test_payment', [AuctionsController::class, 'test_payment'])->name('test_payment');

Route::get('/language/{lang}', [HomeController::class, 'change_language_web'])->name('language')->middleware('lang');
Route::group(['prefix' => $locale, 'middleware' => 'lang'], function () {


    Route::get('rate_user_ajax', [UsersController::class, 'rate_user_ajax'])->name('rate_user_ajax');
    Route::post('/save-token', [HomeController::class, 'saveToken'])->name('save-token');

    Route::get('/', [HomeController::class, 'home'])->name('home');
    Route::get('/login', [UsersController::class, 'login_form'])->name('login');
    Route::view('register_terms', 'site.users.usage_terms')->name('register_terms');
    Route::view('register', 'site.users.register')->name('register');
    Route::post('/register_store', [UsersController::class, 'register_store'])->name('register_store');
    Route::view('activate_account', 'site.users.sending_code')->name('activate_account');
    Route::post('/activate_account_store', [UsersController::class, 'activate_account_store'])->name('activate_account_store');
    Route::post('/authentication', [UsersController::class, 'authentication'])->name('authentication');
    Route::view('forget_password', 'site.users.forget_password')->name('forget_password');

    Route::view('user_check_code', 'site.users.check_code')->name('user_check_code');
    Route::view('user_forget_change_password', 'site.users.forget_change_password')->name('user_forget_change_password');
    Route::post('forget_password_post', [UsersController::class, 'forget_password_post'])->name('forget_password_post');
    Route::post('check_code', [UsersController::class, 'check_code'])->name('check_code');
    Route::post('forget_change_password', [UsersController::class, 'forget_change_password'])->name('forget_change_password');
    Route::get('auctions/{flag}', [AuctionsController::class, 'auctions'])->name('auctions');
    Route::get('advertisement_details/{ad_id}', [HarajProductsController::class, 'advertisement_details'])->name('advertisement_details');
    Route::get('get_harajs_parent', [HarajProductsController::class, 'get_harajs_parent'])->name('get_harajs_parent');
    Route::get('get_harajs_child', [HarajProductsController::class, 'get_harajs_child'])->name('get_harajs_child');
    Route::get('ad_more/{id}', [HarajProductsController::class, 'ad_more'])->name('ad_more');
    Route::get('search_haraj', [HarajProductsController::class, 'search_haraj'])->name('search_haraj');
    Route::get('search_in_header', [HomeController::class, 'search_in_header'])->name('search_in_header');
    Route::get('search_auction', [AuctionsController::class, 'search_auction'])->name('search_auction');
    Route::get('auction_details/{id}', [AuctionsController::class, 'auction_details'])->name('auction_details');

    Route::get('favourite_auction', [AuctionsController::class, 'favourite_auction'])->name('favourite_auction');
    Route::get('termsAndPolicy', [HomeController::class, 'termsAndPolicy'])->name('termsAndPolicy');
    Route::get('policy', [HomeController::class, 'policy'])->name('policy');
    Route::get('banned_products', [HomeController::class, 'banned_products'])->name('banned_products');
    Route::get('security_policies', [HomeController::class, 'security_policies'])->name('security_policies');
    Route::get('common_questions', [HomeController::class, 'common_questions'])->name('common_questions');
    Route::get('contact_us', [HomeController::class, 'contact_us'])->name('contact_us');
    Route::post('contactUs', [HomeController::class, 'contactUs'])->name('contactUs');

    Route::get('userProfile/{user_id}', [HomeController::class, 'userProfile'])->name('userProfile');

    Route::get('next_auction', [AuctionsController::class, 'next_auction'])->name('next_auction');






    Route::group(['middleware' => 'user', 'prefix' => 'user'], function () {

        Route::get('/payment', [UsersController::class, 'payment'])->name('payment');
        Route::post('/payment_submit', [UsersController::class, 'payment_submit'])->name('payment_submit');


        Route::get('/logout', [UsersController::class, 'logout'])->name('logout');
        Route::get('/profile', [UsersController::class, 'profile'])->name('profile');
        Route::post('change_old_password', [UsersController::class, 'change_old_password'])->name('change_old_password');
        Route::post('change_email', [UsersController::class, 'change_email'])->name('change_email');
        Route::post('change_image', [UsersController::class, 'change_image'])->name('change_image');
        Route::get('auctions/{flag}/{user_id?}', [UsersController::class, 'user_auctions'])->name('user_auctions');
        Route::post('change_mobile', [UsersController::class, 'change_mobile'])->name('change_mobile');
        Route::post('change_username', [UsersController::class, 'change_username'])->name('change_username');
        Route::get('complaints', [UsersController::class, 'complaints'])->name('complaints');
        Route::post('send_complaint', [UsersController::class, 'send_complaint'])->name('send_complaint');
        Route::get('commission', [UsersController::class, 'commission'])->name('commission');
        Route::get('calculate_commission', [UsersController::class, 'calculate_commission'])->name('calculate_commission');
        Route::get('favourites', [UsersController::class, 'favourites'])->name('favourites');
        Route::get('harajs/{user_id}', [UsersController::class, 'user_harajs'])->name('user_harajs');
        Route::get('notifications', [UsersController::class, 'notifications'])->name('notifications');
        Route::get('delete_notifications', [UsersController::class, 'delete_notifications'])->name('delete_notifications');
        Route::post('rate_user/{user_id}', [UsersController::class, 'rate_user'])->name('rate_user');

// PAYMENT

        Route::get('open_payment_gate/{method}/{auction_id}', [HyperPayController::class, 'open_payment_gate'])->name('open_payment_gate');
        Route::get('hyperpay_results/{checkoutId}/{method}/{auction_id}', [HyperPayController::class, 'hyperpay_results'])->name('hyperpay_results');

        // Haraj Ads
        Route::get('haraj_type', [HarajProductsController::class, 'haraj_type'])->name('haraj_type');
        Route::get('save_type', [HarajProductsController::class, 'save_type'])->name('save_type');
        Route::get('map', [HarajProductsController::class, 'map'])->name('map');
        Route::get('pledge', [HarajProductsController::class, 'pledge'])->name('pledge');

        Route::get('select_location', [HarajProductsController::class, 'select_location'])->name('select_location');
        Route::get('accept_terms', [HarajProductsController::class, 'accept_terms'])->name('accept_terms');
        Route::get('area', [HarajProductsController::class, 'area'])->name('area');
        Route::get('choose_area', [HarajProductsController::class, 'choose_area'])->name('choose_area');
        Route::get('choose_city', [HarajProductsController::class, 'choose_city'])->name('choose_city');
        Route::get('choose_hay', [HarajProductsController::class, 'choose_hay'])->name('choose_hay');
        Route::post('upload_images', [HarajProductsController::class, 'upload_images'])->name('upload_images');
        Route::get('add_advertisement', [HarajProductsController::class, 'add_advertisement'])->name('add_advertisement');
        Route::post('store_advertisement', [HarajProductsController::class, 'store_advertisement'])->name('store_advertisement');
        Route::get('sub_categories', [HarajProductsController::class, 'sub_categories'])->name('sub_categories');
        Route::get('check_car_option', [HarajProductsController::class, 'check_car_option'])->name('check_car_option');
        Route::post('report/{ad_id}', [HarajProductsController::class, 'report'])->name('report');
        Route::get('delete_ad/{ad_id}', [HarajProductsController::class, 'delete_ad'])->name('delete_ad');
        Route::post('send_speed_message/{receiver_id}', [HarajProductsController::class, 'send_speed_message'])->name('send_speed_message');
        Route::post('comment', [HarajProductsController::class, 'comment'])->name('comment');
        Route::get('edit_ad/{ad_id}', [HarajProductsController::class, 'edit_ad'])->name('edit_ad');
        Route::get('favourite_ad', [HarajProductsController::class, 'favourite_ad'])->name('favourite_ad');
        Route::get('delete_image/{image_id}', [HarajProductsController::class, 'delete_image'])->name('delete_image');
        Route::post('update_ad/{ad_id}', [HarajProductsController::class, 'update_ad'])->name('update_ad');
        Route::get('messages/{id?}', [MessagesController::class, 'messages'])->name('messages');
        Route::post('send_out_message', [MessagesController::class, 'send_out_message'])->name('send_out_message');
        Route::post('send_message', [MessagesController::class, 'send_message'])->name('send_message');
        Route::post('search_rooms', [MessagesController::class, 'search_rooms'])->name('search_rooms');
        Route::get('delete_message/{id}', [MessagesController::class, 'delete_message'])->name('delete_message');

        Route::get('auction_term', [AuctionsController::class, 'auction_term'])->name('auction_term');
        Route::get('auction_area', [AuctionsController::class, 'auction_area'])->name('auction_area');


        // Route::get('auction_cities', [AuctionsController::class, 'auction_cities'])->name('auction_cities');
        Route::get('auction_hays', [AuctionsController::class, 'auction_hays'])->name('auction_hays');
        Route::get('auction_form_city', [AuctionsController::class, 'auction_form_city'])->name('auction_form_city');
        Route::get('auction_form_hay', [AuctionsController::class, 'auction_form_hay'])->name('auction_form_hay');
        Route::get('choose_auction_hay', [AuctionsController::class, 'choose_auction_hay'])->name('choose_auction_hay');
        Route::get('choose_auction_image', [AuctionsController::class, 'choose_auction_image'])->name('choose_auction_image');
        Route::post('auction_upload_images', [AuctionsController::class, 'auction_upload_images'])->name('auction_upload_images');
        Route::get('auction_map', [AuctionsController::class, 'auction_map'])->name('auction_map');
        Route::get('auction_select_location', [AuctionsController::class, 'auction_select_location'])->name('auction_select_location');
        Route::get('add_auction', [AuctionsController::class, 'add_auction'])->name('add_auction');
        Route::post('add_auction_form', [AuctionsController::class, 'add_auction_form'])->name('add_auction_form');
        Route::post('report_auction/{id}', [AuctionsController::class, 'report_auction'])->name('report_auction');
        Route::get('edit_auction/{id}', [AuctionsController::class, 'edit_auction'])->name('edit_auction');
        Route::get('delete_image_auction/{id}', [AuctionsController::class, 'delete_image_auction'])->name('delete_image_auction');
        Route::get('delete_image_auction/{id}', [AuctionsController::class, 'delete_image_auction'])->name('delete_image_auction');
        Route::post('update_auction/{id}', [AuctionsController::class, 'update_auction'])->name('update_auction');
        Route::post('confirmation_sale', [AuctionsController::class, 'confirmation_sale'])->name('confirmation_sale');
        Route::get('subscribe_auction/{auction_id}', [AuctionsController::class, 'subscribe_auction'])->name('subscribe_auction');
        Route::post('subscribe_auction_payment', [AuctionsController::class, 'subscribe_auction_payment'])->name('subscribe_auction_payment');
        Route::get('delivery_codes/{auction_id}', [AuctionsController::class, 'delivery_codes'])->name('delivery_codes');
        Route::post('check_receive_code', [AuctionsController::class, 'check_receive_code'])->name('check_receive_code');
        Route::get('payment_auction_in/{id}', [AuctionsController::class, 'payment_auction_in'])->name('payment_auction_in');
        Route::get('delete_auction/{auction_id}', [AuctionsController::class, 'delete_auction'])->name('delete_auction');
        Route::post('report_comment/{comment_id}', [HarajProductsController::class, 'report_comment'])->name('report_comment');

        Route::post('add_mediation_request', [MediationRequestsController::class, 'add_mediation_request'])->name('add_mediation_request');

        Route::post('payment_checkout', [AdOrdersController::class, 'payment_checkout'])->name('payment_checkout');

        Route::get('formPayment/{payment_method}/{ad_id}', [AdOrdersController::class, 'formPayment'])->name('formPayment');

    });

});

